@@ -155,10 +155,18 @@ class KakiRequestHandler
 				retry
 			end
 		rescue 
-			unless command == 'error' then
+			if command != 'error' then
 				command = 'error'
 				@exception = $!
 				retry
+			else # if error in error page generating...
+				self.response_header['Language'] = 'en';
+				self.response_header['Content-Type'] = "text/plain"
+				self.response_header['Charset'] = "UTF-8"
+				bodyText = $!.inspect + "\n"
+				bodyText += $!.to_s + "\n"
+				bodyText += $!.backtrace.join("\n")  + "\n"
+				self.response_body = bodyText;
 			end
 		end
 	end
@@ -197,8 +205,10 @@ protected
 
 	def script_path
 		unless @script_path then
-			@script_path = self.request_variables['SCRIPT_NAME'].to_s
-			@script_path = '/' if @script_path.length <= 0
+			@script_path = self.request_variables['SCRIPT_NAME']
+			if @script_path == nil || @script_path.length <= 0 then
+				@script_path = '/';
+			end
 		end
 		@script_path
 	end
@@ -224,7 +234,7 @@ protected
 
 	def remote_address
 		unless @remote_address then
-			@remote_address = request_variables['REMOTE_ADDR']
+			@remote_address = request_variables['REMOTE_ADDR'].to_s
 		end
 		@remote_address
 	end
@@ -982,7 +992,12 @@ protected
 
 	def request_language_list()
 		unless @request_language_list then
-			accept_language = request_variables['HTTP_ACCEPT_LANGUAGE'].to_s.untaint
+#			accept_language = request_variables['HTTP_ACCEPT_LANGUAGE'].to_s.untaint
+			if request_variables['HTTP_ACCEPT_LANGUAGE'] then
+				accept_language = request_variables['HTTP_ACCEPT_LANGUAGE'].dup.untaint
+			else
+				accept_language = '';
+			end
 			@request_language_list = accept_language.split(',')
 			@request_language_list.collect!{ |lang_prop|
 				lang, q = lang_prop.split(';q=')
